@@ -7,6 +7,7 @@ from .emr_serverless import Session
 @click.option("--application-id", default=None, help="Application ID", required=True)
 @click.option("--job-role-arn", default=None, help="Job Role ARN", required=True)
 @click.option("--s3-bucket", default=None, help="S3 bucket", required=True)
+@click.option("--region", default=None, help="Region", required=False)
 @click.option(
     "--file",
     "-f",
@@ -15,14 +16,14 @@ from .emr_serverless import Session
     type=click.Path(exists=True, dir_okay=False),
 )
 @click.argument("sql_statement", required=False)
-def run(application_id, job_role_arn, s3_bucket, sql_statement, file):
+def run(application_id, job_role_arn, s3_bucket, region, sql_statement, file):
     if file and sql_statement:
         raise click.UsageError("Cannot use --file and query string at the same time.")
     if not file and not sql_statement:
         raise click.UsageError("Must specify either --file or query string.")
-    if not file.endswith(".sql") and not file.endswith(".ipynb"):
+    if file and (not file.endswith(".sql") and not file.endswith(".ipynb")):
         raise click.UsageError("File must be a .sql or .ipynb file.")
-    session = Session(application_id, job_role_arn, s3_bucket)
+    session = Session(application_id, job_role_arn, s3_bucket, region)
     session.start_application()
     jobrunid: str
     if sql_statement:
